==> eslint-3.2.2.tgz: package/lib/rules/no-implicit-globals.js <==
/**
 * @fileoverview Rule to check for implicit global variables and functions.
 * @author Joshua Peek
 */

"use strict";

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

module.exports = {
    meta: {
        docs: {
            description: "disallow `var` and named `function` declarations in the global scope",
            category: "Best Practices",
            recommended: false
        },

        schema: []
    },

    create: function(context) {
        return {
            Program: function() {
                let scope = context.getScope();

                scope.variables.forEach(function(variable) {
                    if (variable.writeable) {
                        return;
                    }

                    variable.defs.forEach(function(def) {
                        if (def.type === "FunctionName" || (def.type === "Variable" && def.parent.kind === "var")) {
                            context.report(def.node, "Implicit global variable, assign as global property instead.");
                        }
                    });
                });

                scope.implicit.variables.forEach(function(variable) {
                    let scopeVariable = scope.set.get(variable.name);

                    if (scopeVariable && scopeVariable.writeable) {
                        return;
                    }

                    variable.defs.forEach(function(def) {
                        context.report(def.node, "Implicit global variable, assign as global property instead.");
                    });
                });
            }
        };

    }
};

==> eslint-3.4.0.tgz: package/lib/rules/no-implicit-globals.js <==
/**
 * @fileoverview Rule to check for implicit global variables and functions.
 * @author Joshua Peek
 */

"use strict";

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

module.exports = {
    meta: {
        docs: {
            description: "disallow `var` and named `function` declarations in the global scope",
            category: "Best Practices",
            recommended: false
        },

        schema: []
    },

    create(context) {
        return {
            Program() {
                const scope = context.getScope();

                scope.variables.forEach(function(variable) {
                    if (variable.writeable) {
                        return;
                    }

                    variable.defs.forEach(function(def) {
                        if (def.type === "FunctionName" || (def.type === "Variable" && def.parent.kind === "var")) {
                            context.report(def.node, "Implicit global variable, assign as global property instead.");
                        }
                    });
                });

                scope.implicit.variables.forEach(function(variable) {
                    const scopeVariable = scope.set.get(variable.name);

                    if (scopeVariable && scopeVariable.writeable) {
                        return;
                    }

                    variable.defs.forEach(function(def) {
                        context.report(def.node, "Implicit global variable, assign as global property instead.");
                    });
                });
            }
        };

    }
};
